"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
var react_1 = __importStar(require("react"));
var common_1 = require("../../../../common");
var react_redux_1 = require("react-redux");
var hooks_1 = require("../../../../hooks");
var permissions_1 = require("../../permissions");
var account_1 = require("../account");
var lodash_1 = require("lodash");
var layouts_1 = require("../../../../ui/layouts");
var actions_1 = require("../../actions");
var actions_2 = require("../../../app_permissions/actions");
var core_1 = require("@material-ui/core");
var lookForFunction = function (list, look_for_text) {
    return lodash_1.pickBy(list, function (permission) {
        return (permission.codename.toString().toLowerCase().includes(look_for_text.toString().toLowerCase()) ||
            (permission.name_plus ? permission.name_plus.toString().toLowerCase().includes(look_for_text.toString().toLowerCase()) : true));
    });
};
var UserDetail = react_1.memo(function (props) {
    var id = props.match.params.id;
    var dispatch = react_redux_1.useDispatch();
    var user_permission = hooks_1.useHasPermissions(permissions_1.USERS_PERMISSIONS);
    var loadData = function () {
        var getPermissionGroups = function () { return dispatch(actions_2.fetchPermissionsGroups({ callback: function () { return dispatch(actions_1.fetchUser(id)); } })); };
        dispatch(actions_2.fetchPermissionsActive({ callback: getPermissionGroups }));
    };
    react_1.useEffect(function () {
        loadData();
        return function () {
            dispatch(actions_1.clearUsers());
            dispatch(actions_2.clearPermissions());
            dispatch(actions_2.clearPermissionsGroups());
        };
    }, []);
    var user = react_redux_1.useSelector(function (state) { return state.users[id]; });
    var permissions = react_redux_1.useSelector(function (state) { return state.permissions; });
    var permissions_groups = react_redux_1.useSelector(function (state) { return state.permissions_groups; });
    var updatePermission = function (permission) {
        dispatch(actions_1.addPermissionUser(id, permission.id, { callback: function () { return dispatch(actions_1.fetchUser(id)); } }));
    };
    var updateGroup = function (group) {
        dispatch(actions_1.addGroupUser(id, group.id, { callback: function () { return dispatch(actions_1.fetchUser(id)); } }));
    };
    if (!user) {
        return react_1.default.createElement("div", null, "Cargando...");
    }
    var groups = user.groups, user_permissions = user.user_permissions;
    // @ts-ignore
    var permission_in_groups = lodash_1.flatMap(lodash_1.map(lodash_1.pickBy(permissions_groups, function (g) { return groups.includes(g.id); }), function (p) { return p.permissions; }));
    permissions = lodash_1.mapKeys(lodash_1.map(permissions, function (p) { return (__assign(__assign({}, p), { 
        // @ts-ignore
        is_permission_user: user_permissions.includes(p.id), is_permission_user_group: permission_in_groups.includes(p.id) })); }), 'id');
    groups = lodash_1.map(groups, function (g) { return (__assign(__assign({}, g), { is_group_user: groups.includes(g.id) })); });
    return react_1.default.createElement(layouts_1.DetailLayout, { permissions: user_permission, singular_name: 'Usuario', title: "Detalle de " + user.to_string, loadData: loadData, info_items: [
            {
                id: 1,
                label: 'Nombre',
                text_value: user.to_string,
                className: 'col-12 col-sm-6 col-md-4'
            },
            {
                id: 2,
                label: 'Email',
                text_value: user.email,
                className: 'col-12 col-sm-6 col-md-4'
            },
            {
                id: 3,
                label: 'Fecha Nacimiento',
                text_value: common_1.dateFormatOne(user.date_of_birth),
                className: 'col-12 col-sm-6 col-md-4'
            },
            {
                id: 4,
                label: 'Activo',
                className: 'col-12 col-sm-4 col-md-3',
                // @ts-ignore
                icon_value: user.is_active ? 'check-circle' : 'times'
            },
            {
                id: 5,
                label: 'Staff',
                className: 'col-12 col-sm-4 col-md-3',
                // @ts-ignore
                icon_value: user.is_staff ? 'check-circle' : 'times'
            },
            {
                id: 6,
                label: 'Super Usuario',
                className: 'col-12 col-sm-4 col-md-3',
                // @ts-ignore
                icon_value: user.is_superuser ? 'check-circle' : 'times'
            }
        ] },
        react_1.default.createElement(account_1.ManageAccount, { user_id: user.id, is_mine: false }),
        react_1.default.createElement(core_1.Typography, { variant: "h3", gutterBottom: true, color: "primary" }, "Permisos"),
        react_1.default.createElement(layouts_1.LookingForListFilter, null, function (look_for_field) {
            // @ts-ignore
            var group_filtered_list = lookForFunction(permissions, look_for_field);
            return (react_1.default.createElement("div", { className: "row" }, lodash_1.map(group_filtered_list, function (p) { return react_1.default.createElement("div", { key: p.id, className: 'col-12 col-md-6 col-lg-4 col-xl-3' },
                react_1.default.createElement(core_1.FormControlLabel, { control: react_1.default.createElement(core_1.Checkbox, { key: p.id, 
                        // @ts-ignore
                        disabled: p.is_permission_user_group || !user_permission.change_permission_user, 
                        // @ts-ignore
                        checked: p.is_permission_user || p.is_permission_user_group, onChange: function () { return updatePermission(p); }, color: 'primary' }), label: 
                    // @ts-ignore
                    p.is_permission_user_group ?
                        react_1.default.createElement(core_1.Badge, { badgeContent: 'G', color: "secondary" }, p.to_string) :
                        react_1.default.createElement(react_1.Fragment, null, p.to_string) })); })));
        }),
        permissions_groups && react_1.default.createElement("div", { className: "col-12" },
            react_1.default.createElement("div", { className: "card" },
                react_1.default.createElement("div", { className: "card-body" },
                    react_1.default.createElement("div", { className: "card-title" },
                        react_1.default.createElement(core_1.Typography, { variant: "h5", gutterBottom: true, color: "primary" }, "Grupos")),
                    react_1.default.createElement("div", { className: "row pl-3" }, lodash_1.map(permissions_groups, function (g) {
                        return (react_1.default.createElement(react_1.Fragment, { key: g.id },
                            react_1.default.createElement("div", { className: "col-12" },
                                react_1.default.createElement(core_1.Typography, { variant: "h6", gutterBottom: true, color: "primary" },
                                    g.to_string,
                                    react_1.default.createElement(core_1.Checkbox, { key: g.id, disabled: !user_permission.change_permission_user, 
                                        // @ts-ignore
                                        checked: g.is_group_user, onChange: function () { return updateGroup(g); }, color: 'primary' }))),
                            lodash_1.map(g.permissions, function (p) {
                                return (
                                // @ts-ignore
                                react_1.default.createElement("div", { key: p, className: 'col-12 col-md-6 col-lg-4 col-xl-3' },
                                    react_1.default.createElement("span", null,
                                        " ",
                                        // @ts-ignore
                                        permissions[p] && permissions[p].to_string)));
                            })));
                    }))))));
});
exports.UserDetail = UserDetail;
