"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var axios_1 = __importDefault(require("axios"));
var index_1 = require("../index");
var redux_form_1 = require("redux-form");
var createRequest = function (request, options) {
    var _a = options.dispatches, dispatches = _a === void 0 ? null : _a, _b = options.callback, callback = _b === void 0 ? null : _b, _c = options.callback_error, callback_error = _c === void 0 ? null : _c, _d = options.dispatch_method, dispatch_method = _d === void 0 ? null : _d, _e = options.clear_action_type, clear_action_type = _e === void 0 ? null : _e, _f = options.loaded_message, loaded_message = _f === void 0 ? '' : _f, _g = options.show_cargando, show_cargando = _g === void 0 ? true : _g;
    if (clear_action_type) {
        dispatch_method({ type: clear_action_type });
    }
    if (dispatch_method && show_cargando) {
        dispatch_method(index_1.loading(loaded_message));
    }
    return request
        .then(function (response) {
        if (dispatches) {
            dispatches(response);
        }
        if (dispatch_method) {
            if (response.data && response.data.result) {
                dispatch_method(index_1.notificarAction(response.data.result, { title: loaded_message, time: 5 }));
            }
            dispatch_method(index_1.noLoading());
        }
        if (callback) {
            callback(response.data);
        }
    }).catch(function (error) {
        if (callback_error) {
            callback_error(error);
        }
        if (error.response) {
            if (error.response.status === 400) {
                dispatch_method(index_1.noLoading());
                if (error.response && error.response.data) {
                    if (error.response.data['non_field_errors']) {
                        error.response.data['_error'] = error.response.data['non_field_errors'];
                        dispatch_method(index_1.notificarErrorAction(error.response.data['non_field_errors']));
                    }
                    if (error.response.data['_error']) {
                        dispatch_method(index_1.notificarErrorAction(error.response.data['_error']));
                    }
                    throw new redux_form_1.SubmissionError(error.response.data);
                }
            }
            else if (error.response.status === 401) {
                var detail = error.response.data.detail;
                if (detail === 'Las credenciales de autenticación no se proveyeron.') {
                    dispatch_method(index_1.show_loading_error('Debe de autenticarse de nuevo', 'Problemas de Autenticación!'));
                }
            }
            else if (error.response.status === 403) {
                dispatch_method(index_1.show_loading_error(error.response.data['detail'], error.response.status + ": " + error.response.statusText));
                dispatch_method(index_1.notificarErrorAction(error.response.data['detail']));
                // @ts-ignore
            }
            else if (402 < error.response.status < 600) {
                // @ts-ignore
                dispatch_method(index_1.show_loading_error(error.response.data, error.response.status + ": " + error.response.statusText));
                dispatch_method(index_1.notificarErrorAction(error.response.status));
            }
            else {
                if (error.response.data) {
                    console.log(error.response);
                }
            }
        }
        else if (!error.response) {
            if (error.message === 'Network Error') {
                dispatch_method(index_1.show_loading_error(error.stack, 'Error de red'));
            }
            else {
                dispatch_method(index_1.show_loading_error(error.stack, error.message));
            }
        }
    });
};
exports.createRequest = createRequest;
var fetchListPostURLParameters = function (url, method, values, options) {
    if (options === void 0) { options = {}; }
    console.log("%cAPI METODO " + method.toUpperCase() + " CON PARMAETROS - %c" + url.toUpperCase() + " - %cID", 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Ejecutando " + method.toUpperCase() + " en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    axios_1.default.defaults.headers["Content-Type"] = 'application/x-www-form-urlencoded;charset=UTF-8';
    var FULL_URL = url + "/" + method + "/";
    var request = axios_1.default.post(FULL_URL, values);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.fetchListPostURLParameters = fetchListPostURLParameters;
var fetchListGet = function (url, options) {
    if (options === void 0) { options = {}; }
    console.log("%cFETCH LIST - %c" + url.toUpperCase(), 'color:red', 'color:blue');
    var loaded_message = "Consultando " + url.toUpperCase();
    var FULL_URL = url + "/?format=json";
    axios_1.default.defaults.headers["Content-Type"] = 'application/json';
    var request = axios_1.default.get(FULL_URL);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.fetchListGet = fetchListGet;
var fetchListGetURLParameters = function (url, options) {
    if (options === void 0) { options = {}; }
    console.log("%cFETCH LIST PARAMETROS - %c" + url.toUpperCase(), 'color:red', 'color:blue');
    var loaded_message = "Consultando " + url.toUpperCase();
    var FULL_URL = url + "&format=json";
    axios_1.default.defaults.headers["Content-Type"] = 'application/json';
    var request = axios_1.default.get(FULL_URL);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.fetchListGetURLParameters = fetchListGetURLParameters;
var fetchObject = function (url, id, options) {
    if (options === void 0) { options = {}; }
    console.log("%cFETCH OBJETO - %c" + url.toUpperCase() + " - %cID " + id, 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Consultando elemento en " + url.toUpperCase();
    var FULL_URL = url + "/" + id + "/?format=json";
    axios_1.default.defaults.headers["Content-Type"] = 'application/json';
    var request = axios_1.default.get(FULL_URL);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.fetchObject = fetchObject;
var updateObject = function (url, id, values, options, config) {
    if (options === void 0) { options = {}; }
    if (config === void 0) { config = null; }
    console.log("%cUPDATE OBJETO - %c" + url.toUpperCase() + " - %cID " + id, 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Actualizando elemento en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    axios_1.default.defaults.headers["Content-Type"] = 'application/json';
    var FULL_URL = url + "/" + id + "/";
    var request = axios_1.default.put(FULL_URL, values, config);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.updateObject = updateObject;
var createObject = function (url, values, options) {
    if (options === void 0) { options = {}; }
    console.log("%cCREATE OBJETO - %c" + url.toUpperCase(), 'color:red', 'color:blue');
    var loaded_message = "Creando elemento en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    axios_1.default.defaults.headers["Content-Type"] = 'application/json';
    var FULL_URL = url + "/";
    var request = axios_1.default.post(FULL_URL, values);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.createObject = createObject;
var deleteObject = function (url, id, options) {
    if (options === void 0) { options = {}; }
    console.log("%cDELETE OBJETO - %c" + url.toUpperCase() + " - %cID " + id, 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Eliminando elemento en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    axios_1.default.defaults.headers["Content-Type"] = 'application/json';
    var FULL_URL = url + "/" + id + "/";
    var request = axios_1.default.delete(FULL_URL);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.deleteObject = deleteObject;
var uploadFile = function (url, id, method, values, options) {
    if (options === void 0) { options = {}; }
    console.log("%cAPI UPLOAD ARCHIVO " + method.toUpperCase() + " CON PARMAETROS - %c" + url.toUpperCase() + " - %cID " + id, 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Ejecutando " + method.toUpperCase() + " en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    axios_1.default.defaults.headers["Content-Type"] = 'application/x-www-form-urlencoded;charset=UTF-8';
    var FULL_URL = url + "/" + id + "/" + method + "/";
    var request = axios_1.default.post(FULL_URL, values, { responseType: 'arraybuffer' });
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.uploadFile = uploadFile;
var callApiMethodPost = function (url, id, method, options) {
    if (options === void 0) { options = {}; }
    console.log("%cAPI METODO " + method.toUpperCase() + " - %c" + url.toUpperCase() + " - %cID " + id, 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Ejecutando " + method.toUpperCase() + " en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    var FULL_URL = url + "/" + id + "/" + method + "/";
    var request = axios_1.default.post(FULL_URL);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.callApiMethodPost = callApiMethodPost;
var callApiMethodPostParameters = function (url, id, method, values, options) {
    if (id === void 0) { id = null; }
    if (options === void 0) { options = {}; }
    console.log("%cAPI METODO " + method.toUpperCase() + " CON PARMAETROS - %c" + url.toUpperCase() + " - %cID " + id, 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Ejecutando " + method.toUpperCase() + " en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    var _a = options.content_type, content_type = _a === void 0 ? null : _a;
    axios_1.default.defaults.headers["Content-Type"] = content_type ? content_type : 'application/x-www-form-urlencoded;charset=UTF-8';
    var FULL_URL = null;
    if (id) {
        FULL_URL = url + "/" + id + "/" + method + "/";
    }
    else {
        FULL_URL = url + "/" + method + "/";
    }
    var request = axios_1.default.post(FULL_URL, values);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.callApiMethodPostParameters = callApiMethodPostParameters;
var fetchObjectWithParameterPDF = function (url, options) {
    if (options === void 0) { options = {}; }
    console.log("%cFETCH LIST PARAMETROS - %c" + url.toUpperCase() + " PARA PDF", 'color:red', 'color:blue');
    var FULL_URL = url + "&format=json";
    var request = axios_1.default.get(FULL_URL, { responseType: 'arraybuffer' });
    return createRequest(request, __assign(__assign({}, options), { loaded_message: '' }));
};
exports.fetchObjectWithParameterPDF = fetchObjectWithParameterPDF;
var callApiMethodPostParametersPDF = function (url, id, method, parameters, options) {
    if (options === void 0) { options = {}; }
    console.log("%cAPI METODO " + method.toUpperCase() + " CON PARMAETROS - %c" + url.toUpperCase() + " - %cID " + id + " PARA PDF", 'color:red', 'color:blue', 'color:green');
    var loaded_message = "Ejecutando PDF " + method.toUpperCase() + " en " + url.toUpperCase();
    axios_1.default.defaults.xsrfHeaderName = "X-CSRFTOKEN";
    axios_1.default.defaults.xsrfCookieName = "csrftoken";
    var FULL_URL = url + "/" + id + "/" + method + "/";
    var request = axios_1.default.post(FULL_URL, parameters, { responseType: 'arraybuffer' });
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.callApiMethodPostParametersPDF = callApiMethodPostParametersPDF;
var fetchApiRestGet = function (url, options, additional_header) {
    if (options === void 0) { options = {}; }
    if (additional_header === void 0) { additional_header = {}; }
    console.log("%cFETCH Api Rest - %c" + url.toUpperCase(), 'color:red', 'color:blue');
    var loaded_message = "Consultando " + url.toUpperCase();
    var FULL_URL = "" + url;
    axios_1.default.defaults.headers = __assign(__assign({}, additional_header), { "Content-Type": "application/json" });
    var request = axios_1.default.get(FULL_URL);
    return createRequest(request, __assign(__assign({}, options), { loaded_message: loaded_message }));
};
exports.fetchApiRestGet = fetchApiRestGet;
